==> gail-0.1.tar.gz: gail-0.1/gail/gailframefactory.c <==
/* GAIL - The GNOME Accessibility Implementation Library
 * Copyright 2001 Sun Microsystems Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <gtk/gtkframe.h>
#include <gtk/gtkaccessible.h>
#include "gailframefactory.h"
#include "gailframe.h"

static void gail_frame_factory_class_init (
                                GailFrameFactoryClass        *klass);

static AtkObject* gail_frame_factory_create_accessible (
                                GObject                       *obj);

static AtkObjectFactoryClass    *parent_class = NULL;

GType
gail_frame_factory_get_type ()
{
  static GType type = 0;

  if (!type) 
  {
    static const GTypeInfo tinfo =
    {
      sizeof (GailFrameFactoryClass),
      (GBaseInitFunc) NULL, /* base init */
      (GBaseFinalizeFunc) NULL, /* base finalize */
      (GClassInitFunc) gail_frame_factory_class_init, /* class init */
      (GClassFinalizeFunc) NULL, /* class finalize */
      NULL, /* class data */
      sizeof (GailFrameFactory), /* instance size */
      0, /* nb preallocs */
      (GInstanceInitFunc) NULL, /* instance init */
      NULL /* value table */
    };
    type = g_type_register_static (ATK_TYPE_OBJECT_FACTORY, 
                           "GailFrameFactory" , &tinfo, 0);
  }

  return type;
}

static void 
gail_frame_factory_class_init (GailFrameFactoryClass *klass)
{
  AtkObjectFactoryClass *class = ATK_OBJECT_FACTORY_CLASS (klass);

  parent_class = g_type_class_ref (ATK_TYPE_OBJECT_FACTORY);

  class->create_accessible = gail_frame_factory_create_accessible;
}


AtkObjectFactory* gail_frame_factory_new ()
{
  GObject *factory;

  factory = g_object_new (GAIL_TYPE_FRAME_FACTORY, NULL);

  g_return_val_if_fail (factory != NULL, NULL);
  return ATK_OBJECT_FACTORY (factory);
} 

static AtkObject* 
gail_frame_factory_create_accessible (GObject     *obj)
{
  GtkAccessible *accessible;
  GtkWidget* widget;

  g_return_val_if_fail (GTK_IS_WIDGET(obj), NULL);

  widget = GTK_WIDGET (obj);

  accessible = gail_frame_new (widget);

  g_return_val_if_fail (accessible != NULL, NULL);

  return ATK_OBJECT (accessible);
}

==> gail-0.9.tar.gz: gail-0.9/gail/gailframefactory.c <==
/* GAIL - The GNOME Accessibility Implementation Library
 * Copyright 2001 Sun Microsystems Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include <gtk/gtkframe.h>
#include <gtk/gtkaccessible.h>
#include "gailframefactory.h"
#include "gailframe.h"

static void gail_frame_factory_class_init (
                                GailFrameFactoryClass        *klass);

static AtkObject* gail_frame_factory_create_accessible (
                                GObject                       *obj);

static GType gail_frame_factory_get_accessible_type (void);

GType
gail_frame_factory_get_type (void)
{
  static GType type = 0;

  if (!type) 
  {
    static const GTypeInfo tinfo =
    {
      sizeof (GailFrameFactoryClass),
      (GBaseInitFunc) NULL, /* base init */
      (GBaseFinalizeFunc) NULL, /* base finalize */
      (GClassInitFunc) gail_frame_factory_class_init, /* class init */
      (GClassFinalizeFunc) NULL, /* class finalize */
      NULL, /* class data */
      sizeof (GailFrameFactory), /* instance size */
      0, /* nb preallocs */
      (GInstanceInitFunc) NULL, /* instance init */
      NULL /* value table */
    };
    type = g_type_register_static (ATK_TYPE_OBJECT_FACTORY, 
                           "GailFrameFactory" , &tinfo, 0);
  }

  return type;
}

static void 
gail_frame_factory_class_init (GailFrameFactoryClass *klass)
{
  AtkObjectFactoryClass *class = ATK_OBJECT_FACTORY_CLASS (klass);

  class->create_accessible = gail_frame_factory_create_accessible;
  class->get_accessible_type = gail_frame_factory_get_accessible_type;
}

static AtkObject* 
gail_frame_factory_create_accessible (GObject     *obj)
{
  GtkWidget* widget;

  g_return_val_if_fail (GTK_IS_WIDGET (obj), NULL);

  widget = GTK_WIDGET (obj);

  return gail_frame_new (widget);
}

static GType
gail_frame_factory_get_accessible_type (void)
{
  return GAIL_TYPE_FRAME;
}
